Minecraft Game Modes
On a Prison server, players start in the lowest mine, mine blocks, sell them, and spend the money to rank up (A, B, C... Z). Each rank unlocks a better mine with more valuable blocks. At the last rank they prestige: their rank and money reset in return for a permanent bonus, and the climb starts again. Underneath the mining, Prison is an economy game. A well-run Prison server is mostly a well-balanced spreadsheet and smooth mine resets.
What you'll build: a Paper server with the free Prison plugin, 26 mines linked to 26 ranks, a prestige ladder, sell-all and auto-sell, LuckPerms groups that follow players up the ladder, a protected spawn, a priced economy you've actually tested, backups and a performance plan.
Time: about 3–4 hours for a working server, plus a weekend to build a proper spawn and play-test the first ranks.
Before you start:
- A Minecraft server on the panel running Paper. If you haven't set one up yet, follow Paper and Purpur servers first. Pin a Minecraft version on Startup rather than using
latest. - At least 4 GB of memory for a small server (up to ~20 players), 6–8 GB for 20–60 players. Prison worlds are small, so memory goes on players and plugins, not terrain.
- You know how to open Console and Files in the panel, and how to install plugins.
Choose your Prison core
A "core" is the plugin that runs mines, ranks and selling. Pick one and build everything around it.
| Option | Cost | What it includes | Choose it if |
|---|---|---|---|
| Prison (SpigotMC, by the PrisonTeam) | Free, open source | Mines, rank ladders, prestige, sell-all, auto-sell, auto-pickup/smelt/block, mine bombs, GUIs, about 300 placeholders | You want a complete, free starting point. This guide uses it. |
| Rankup (Rankup3 by Okx) + a separate mine plugin | Paid on SpigotMC, source on GitHub | Rank-up and prestige only, driven by your permission groups through Vault | You want ranks from LuckPerms groups and will handle mines and selling with other plugins. |
| Paid all-in-one cores (for example X-Prison Core on BuiltByBit) | Paid | Mines, tokens, custom pickaxe enchants, gangs, auto-miners | You want token enchants built in and are happy to pay. Check the listing supports your Minecraft version. |
The Prison plugin was updated in June 2026 (version 3.3.1) with builds for current Spigot and Paper. Its page offers two jars: prison.3.3.1.jar for older Minecraft versions and prison26.3.3.1.jar for 1.21+ and newer Paper releases. Download the one that matches your server; the version number will be newer by the time you read this.
Old standalone mine plugins such as MineResetLite are no longer updated for current Minecraft versions. Don't build a new server on them.
Install the plugins
Install these, then restart once at the end.
| Plugin | Where to get it | Why |
|---|---|---|
| Prison | SpigotMC: download the jar, then Files → plugins → Upload |
The core. |
| Vault | SpigotMC or the panel's Plugins page | The bridge that lets Prison talk to your economy and permissions. Prison lists it as strongly suggested; treat it as required. |
| EssentialsX | Minecraft Plugins (Modrinth) | Provides the economy (/balance, /pay, /baltop), plus /spawn, homes and kits. |
| LuckPerms | Minecraft Plugins | Groups, prefixes and per-rank perks. |
| WorldEdit or FastAsyncWorldEdit | Minecraft Plugins | Building spawn and mines. FAWE is much faster on big edits. |
| WorldGuard | Minecraft Plugins or EngineHub | Protects spawn and everything outside the mines. Prison strongly suggests it. |
| PlaceholderAPI | Minecraft Plugins | Shows ranks, balances and mine timers on scoreboards and holograms. |
| CoreProtect | Minecraft Plugins | Logs every block and chest change so you can investigate and roll back. |
| EssentialsX Chat (optional) | Same download as EssentialsX | Shows LuckPerms prefixes in chat. |
- On your server, open Minecraft Plugins and install EssentialsX, LuckPerms, WorldEdit (or FAWE), WorldGuard, PlaceholderAPI and CoreProtect one by one.
- Download Prison and Vault to your computer, then go to Files →
plugins→ Upload and pick both jars. The jars go directly inplugins/, not in a subfolder. - Restart from Console.
- Run
pluginsin the console. Every plugin should be green. A red name failed to load: scroll up in the console to see why (usually a jar for the wrong Minecraft version). - Run
prison version. It lists the modules that loaded and which economy and permission plugins Prison found. You want to see EssentialsX (through Vault) as the economy and LuckPerms as permissions.
Prepare the world
Prison doesn't need a big survival world. A flat or empty world is easier to build in and cheaper to run.
Option A: a flat world (simplest)
Stop the server.
In Files, open
server.propertiesand set:level-name=prison level-type=minecraft\:flat generate-structures=false spawn-monsters=false view-distance=8 simulation-distance=6Start the server. Paper creates a new flat world called
prison. Your oldworldfolder stays untouched in Files in case you need it.
Option B: keep the existing world
If you already built something, keep it and build the mines away from it. Set a world border around the area you'll use.
Turn off things Prison doesn't need
In the console:
gamerule doMobSpawning false
gamerule doFireTick false
gamerule doWeatherCycle false
gamerule doDaylightCycle false
time set day
Then protect the whole world with WorldGuard so that, by default, nobody can break or build anywhere (mines get their own permission in step 6):
rg flag -w prison __global__ passthrough deny
rg flag -w prison __global__ mob-spawning deny
Check it worked: join as a non-op player (or deop yourself temporarily) and try to break a block. You should see a WorldGuard "Hey! Sorry, but you can't break that block here" message.
Generate ranks and mines automatically
Prison can build a complete starter setup in one command. It's the fastest way to learn how the pieces fit, and you can change everything afterwards.
In the console, run:
ranks autoConfigure
This creates:
- Ranks A to Z on the
defaultladder, and mines A to Z, each linked to its matching rank. - Mines filled with blocks that get more valuable from A (cobblestone, stone) to Z (ores and precious blocks).
- 25 prestige ranks on a separate
prestigesladder. - Sell-all preloaded with prices for about 98 items and blocks.
- Auto features: auto pickup, auto smelt and auto block.
- Access by rank: a player can only enter and teleport to mines up to their own rank, without any permission nodes.
The default prices start at 50,000 with a 1.5× multiplier per rank, so each rank costs half again as much as the one before. That compounds fast: by rank Z the price is over a billion. Step 8 shows how to set prices that fit your mines.
Check what it made:
ranks list all
mines list all
mines info A all
ranks autoConfigure help lists its options, such as price=, mult=, prestiges= and prestigeCost=. Run it again with force only on a test copy: it replaces the blocks in every mine.
Build the mines
You place each virtual mine into the world, then decorate around it.
Plan the layout
Most Prison servers use one of two layouts:
- A mine hub: spawn in the middle, with a corridor or portal to each mine. Simple, and players see the mines they haven't unlocked yet.
- Separate areas: each mine sits in its own themed area reached by
/mines tp(alias/mtp). Prettier, but more building.
Space mines at least 64 blocks apart so resetting one mine never touches the area around another.
Size each mine sensibly
| Mine size (W × L × depth) | Blocks | Good for |
|---|---|---|
| 21 × 21 × 30 | ~13,000 | Early mines, small servers |
| 31 × 31 × 40 | ~38,000 | Most mines on a 20–50 player server |
| 51 × 51 × 50 | ~130,000 | One or two showcase mines, busy servers only |
Every block in a mine has to be replaced when it resets. Several medium mines are far cheaper than one giant mine.
Place a mine
- Fly to where mine A should go and stand where its top surface will be.
- Run
mines set area A feet 15 30. This creates the mine below your feet, expanding 15 blocks out in each direction and 30 blocks down. (Prison's own example ismines set area A feet 20 7.) - Or select the corners yourself: run
mines wand, left-click one corner block and right-click the opposite corner, then runmines set area A. The wand can't select air, so build two marker blocks first. - Set where players arrive: stand at the edge of the mine, face it, and run
mines set spawn A. - Give it a border:
mines set liner A walls bright forcebuilds decorative walls. Runmines set liner helpto see other patterns. - Run
mines reset Aand check the mine fills with blocks.
Repeat for B to Z. Use mines tp A to jump between mines while you work.
Let players break blocks in mines
Because you denied building everywhere in step 3, players need a WorldGuard region over each mine that allows breaking:
- Select the mine with WorldEdit:
//wand, then left-click and right-click opposite corners one block outside the mine. rg define mine_arg flag mine_a block-break allowrg flag mine_a item-drop allow
Prison's mine access by rank still stops players breaking blocks in mines they haven't unlocked. Test it: as a fresh player with rank A, you should be able to mine in A but not in B.
Build spawn and decorations with WorldEdit
These WorldEdit commands do most of the work (with FAWE they're identical):
| Command | What it does |
|---|---|
//wand |
Gives the selection axe. Left-click = corner 1, right-click = corner 2. |
//pos1 / //pos2 |
Set corners where you're standing. |
//set stone_bricks |
Fills the selection. |
//walls quartz_block |
Builds walls around the selection. |
//replace dirt grass_block |
Swaps one block type for another. |
//copy then //paste |
Copies a build relative to where you stand. |
//schem load spawn then //paste |
Pastes a schematic you uploaded. |
//undo |
Undoes your last edit. |
Bought or downloaded a spawn schematic? Upload the .schem file through Files into plugins/WorldEdit/schematics/ (or plugins/FastAsyncWorldEdit/schematics/ for FAWE), then //schem load <name> and //paste.
Set spawn when it's done: stand on the spawn point and run /setspawn (EssentialsX), then protect it: select it with //wand and run rg define spawn and rg flag spawn pvp deny.
Set mine reset timers
Each mine refills on a timer, and optionally when it's nearly empty.
- Timer:
mines set resetTime A 300resets mine A every 300 seconds (5 minutes). - Threshold: a mine can also reset early when most blocks are gone. Prison works out blocks to reset = total blocks × (1 − threshold). Run
mines set resetThreshold helpfor the exact syntax on your version. - Notifications:
mines set notification A radius 50warns players within 50 blocks before a reset;withinwarns only players inside the mine;disabledturns it off.
Good starting timers:
| Mine | Players inside at once | Reset every |
|---|---|---|
| A–E (crowded) | many | 180–300 s |
| F–T | some | 300–600 s |
| U–Z | few | 600–900 s |
Stagger the timers so they don't all fire together. Give mines slightly different values (300, 310, 320...) or set them a few seconds apart. If twenty mines reset in the same second, everyone feels it.
How mine resets cost performance
Prison resets mines on the main server thread, in pages: it replaces a slice of blocks each tick and shrinks the slice when the server is busy. Its documentation says it doesn't use async resets because they eventually corrupt server data. Paging keeps one reset from freezing the server, but the total work is the same: a 38,000-block mine resetting every 5 minutes means about 7.6 million block changes an hour per mine.
To keep resets cheap:
- Keep mines medium-sized (see the table in step 5).
- Don't set a reset threshold above about 80%. Prison's docs warn high values cause very frequent resets.
- Don't reset mines nobody is in more often than needed. Late mines can use long timers.
- Check with spark: run
spark tpsduring a reset. Healthy servers stay at 20 TPS with MSPT under 50. Runspark profiler start, wait through two or three resets, thenspark profiler stopand open the link to see how much time mine resets took. Fix lag
Set up rank permissions with LuckPerms tracks
Prison stores each player's rank itself. LuckPerms groups let you hang perks on each rank (a prefix, kits, /fly at rank Z) and show the rank in chat. You keep the two in sync with a track and one Prison ladder command.
Create the groups
In the console, create one group per rank. Group names should match the Prison rank names (LuckPerms stores them in lower case):
lp creategroup a
lp creategroup b
lp creategroup c
...and so on through z. Then make each group inherit the one below, so perks carry upwards:
lp group b parent add a
lp group c parent add b
...through lp group z parent add y. Make a inherit default: lp group a parent add default.
Create the track
A track is an ordered list of groups. Create it and add the groups in order:
lp createtrack mine-ranks
lp track mine-ranks append a
lp track mine-ranks append b
lp track mine-ranks append c
...through z. Check it with lp track mine-ranks info: it should list a to z once each, in order.
Tell Prison to move players along the track
One ladder command runs every time a player ranks up on the default ladder:
ranks ladder command add default lp user {player} parent settrack mine-ranks {targetRank}
{player} becomes the player's name and {targetRank} the rank they're moving to. parent settrack removes the player's other groups on that track and puts them in the right one.
If you already have players, sync them once:
ranks set rank *all* *same*
Add prefixes and perks
lp group a meta setprefix 10 "&7[A] "
lp group m meta setprefix 10 "&b[M] "
lp group z meta setprefix 10 "&6[Z] "
lp group f permission set essentials.workbench true
lp group p permission set essentials.enderchest true
lp group z permission set essentials.fly true
Every player needs Prison's player commands. Give them to the base group:
lp group default permission set ranks.user true
ranks.user allows /rankup and /prestige. Teleporting to mines is controlled by Prison's TP access by rank setting (mines set tpAccessByRank help), so you don't need a permission per mine. If a player can't use a command, run lp verbose on, have them try it, then lp verbose off: the console shows exactly which permission was checked.
Check it worked: create a test player (or use an alt), give them money with eco give <player> 1000000, run /rankup, then lp user <player> info. Their parent group should now be b.
Balance the economy
This is the step that decides whether players stay. The idea is simple: decide how long each rank should take, measure how fast players earn, and set prices from those two numbers.
Step 1: measure blocks per hour
Get a fresh player with a starting pickaxe (whatever your starter kit gives). Mine in mine A for exactly 5 minutes and count the blocks with /sellall sell before and after (or watch the money). Multiply by 12 for blocks per hour. Typical results:
| Pickaxe | Blocks per hour (one player, normal play) |
|---|---|
| Iron, no enchants | ~2,500–3,500 |
| Diamond, Efficiency V | ~5,000–7,000 |
| Netherite, Efficiency V, with a mining speed boost | ~7,000–9,000 |
Use your own measurement, not these numbers. Walking, inventory trips and other players all change it.
Step 2: average block value per mine
For each mine, the average value of a block is the sum of (block price × block percentage). For a mine of 70% cobblestone at $0.50 and 30% coal ore at $3 (sold as coal):
0.70 × 0.50 + 0.30 × 3.00 = $1.25 per block
Prison's mine info shows each mine's block mix and its estimated value. mines info A all lists it.
Step 3: choose a time per rank
A curve that works for most servers: the first rank takes about 15 minutes, and each rank after takes about 10% longer. With 26 ranks that's roughly 25 hours of play to reach Z, with the last rank taking about two and a half hours.
Step 4: price each rank
Rank cost = income per hour in the current mine × hours for this rank.
Here's a worked example: 6,000 blocks per hour, mine A worth $1.00 per block, each mine worth 1.35× the previous, each rank taking 1.1× longer:
| Rank-up | Avg block value in current mine | Income per hour | Time | Price of next rank |
|---|---|---|---|---|
| A → B | $1.00 | $6,000 | 15 min | $1,500 |
| B → C | $1.35 | $8,100 | 16.5 min | $2,228 |
| C → D | $1.82 | $10,935 | 18.2 min | $3,308 |
| D → E | $2.46 | $14,762 | 20 min | $4,912 |
| ... | ×1.35 per rank | ×1.1 per rank | ×~1.49 per rank |
Notice the price grows by 1.35 × 1.1 ≈ 1.49× per rank. That's why Prison's default 1.5× multiplier works, as long as mine values climb about 35% per rank. If your mines climb more slowly, lower the multiplier or players hit a wall.
Set prices:
- All at once on a fresh setup:
ranks autoConfigure price=1500 mult=1.49(on a clean server or test copy). - One rank at a time:
ranks set cost B 1500,ranks set cost C 2228and so on.
Step 5: account for everything that multiplies income
Every multiplier makes players finish faster. Write them all down and include them:
| Source | Typical effect |
|---|---|
| Fortune on ores (with Prison's auto features) | Fortune III averages about 2.2× drops on ores. |
| Auto-sell | No inventory trips: often +20–40% blocks per hour. |
| Sell multipliers (prestige, donor ranks, boosters) | Exactly what they say: ×1.5 is +50% income. |
| Explosive or area enchants, mine bombs | Can multiply blocks per hour 5–20×. The biggest economy breaker. |
If donors get ×1.5 and prestige 10 gives ×2, a donor at prestige 10 earns 3× a new player. Either price for the boosted player and let new players feel slow, or price for new players and accept boosted players fly through. Most servers price for a player with average boosts.
Step 6: prestige
With prestige on, a player at Z can /prestige (and /prestige confirm). By default, plugins/Prison/config.yml resets their money and rank:
prestige:
enabled: true
resetMoney: true
resetDefaultLadder: true
confirmation-enabled: true
Give each prestige a reward that matters, usually a sell multiplier:
sellall multiplier add P1 1.1
sellall multiplier add P2 1.2
sellall multiplier add P3 1.3
Prison can also raise rank costs at each prestige (the ladder's rank cost multiplier; run ranks ladder rankCostMultiplier help). If each prestige raises costs by 10% and income by 10%, they cancel and every prestige takes the same time, which is usually what you want.
Step 7: play-test it
Before launch, play mines A to E yourself with a starter pickaxe and a stopwatch. If A → B takes 5 minutes, your prices are a third of what they should be. Fix it now: changing prices after launch angers everyone who already paid the old ones.
Set up selling and auto-sell
Prison's sell-all sells every sellable item in a player's inventory at the prices you set.
| Command | What it does |
|---|---|
/sellall sell |
Sells the player's inventory. |
/sellall add <ITEM_ID> <VALUE> |
Adds an item, e.g. /sellall add DIAMOND_ORE 40. |
/sellall edit <ITEM_ID> <VALUE> |
Changes a price. |
/sellall auto toggle |
A player turns auto-sell on or off for themselves. |
/sellall multiplier add <Prestige> <Multiplier> |
Gives a prestige rank a sell bonus. |
Prices are stored in sellallconfig.yml inside Prison's plugin folder. Edit them with the commands while the server is running, or edit the file with the server stopped.
Auto features (auto pickup, smelt, block and sell) are controlled in game with prison autofeatures and in Prison's auto features config. Auto pickup sends mined blocks straight to the inventory, so there are no items on the ground: it's both more fun and better for performance.
- Give auto-sell as a rank or donor perk rather than to everyone; it's a strong reward.
- Put a sell sign or NPC near each mine for players without auto-sell.
- Use one sell system. If you also install a shop plugin (EssentialsX
/sellwithworth.yml, or a GUI shop), make sure it doesn't sell the same items at different prices, or players will find the better one.
Pickaxe enchants and progression
Better pickaxes are the main thing players spend on between rank-ups.
- Vanilla enchants (Efficiency, Fortune, Unbreaking) work out of the box. Sell enchanted books in a shop, or let players enchant normally.
- Mine bombs: Prison includes them, so players can blow up an area of a mine. Price them high: each one is many blocks of income at once.
- Custom pickaxe enchants (Explosive, Jackhammer, token-based upgrades) come from paid plugins. RevEnchants (BuiltByBit) is a Prison-style enchant system with its own token economy, and paid cores like X-Prison Core include enchants. Check the listing supports your Minecraft version and Paper before buying, and read the changelog date.
Prison's auto manager can work with some third-party enchant plugins so blocks broken by enchants still go through auto pickup and auto-sell. Prison's guide Auto Manager (in its docs on GitHub) lists which ones.
Cells and plots
Many Prison servers give players a small cell to store items and decorate. Common approaches:
- A cell block built in the prison world, with a WorldGuard region per cell. A region-rental plugin (AreaShop and its community forks) lets players rent a cell for in-game money. Check that the version you download supports your Minecraft version.
- A plot world with PlotSquared, where each player claims a plot. Easier to scale, less themed.
- Private mines: Prison's documentation has a guide for private mines (Configuring Private Mines).
Whatever you choose, cells mean player builds: keep CoreProtect running and back them up like any survival world.
Scoreboards, holograms and the welcome experience
- A scoreboard plugin with PlaceholderAPI can show rank, next rank cost, balance and prestige. Run
prison placeholders helpto list and test Prison's placeholders. - A starter kit: EssentialsX
/kitwith an iron pickaxe, some food and a few torches. Set it to be claimed once. - Tutorial signs or holograms at spawn: how to
/mines tp,/sellall sell,/rankup. - A
/rulespage that bans macros and auto-clickers (or allows them: decide and say so).
Backups and restarts
Prison stores its ranks, mines and player progress in plugins/Prison/. Your economy lives in plugins/Essentials/userdata/. Both must be in every backup; panel backups include everything unless you exclude it.
Set up two schedules in Schedules (times are UTC, see cron times):
Backup every 6 hours
| Field | Value |
|---|---|
| Name | Backup every 6 hours |
| Cron | Minute 0, Hour */6, Day of month *, Month *, Day of week * |
| Only when server is online | Off |
| Task 1 | Send Command: save-all |
| Task 2 | Create Backup, Time Offset 10, ignored files logs |
Daily restart at a quiet time (here 09:00 UTC, 5 am Eastern in summer)
| Task | Action | Offset |
|---|---|---|
| 1 | Send Command: say Restart in 5 minutes. Mines will reset after. |
0 |
| 2 | Send Command: say Restart in 1 minute! |
240 |
| 3 | Send Power Action: Restart | 60 |
Press Run now once on each schedule, then check Backups for a new Successful backup. The backup schedules guide covers how many to keep and how to test a restore.
Performance tuning
Prison servers lag from three things: mine resets, players with area enchants, and too many dropped items. These settings help:
| File | Setting | Value | Why |
|---|---|---|---|
server.properties |
view-distance |
6–8 | Players stay in compact areas. |
server.properties |
simulation-distance |
4–6 | Nothing outside the mines needs ticking. |
config/paper-world-defaults.yml |
chunks.entity-per-chunk-save-limit |
item: 64, experience_orb: 16 |
Stops chunks saving thousands of dropped items. |
config/paper-world-defaults.yml |
collisions.max-entity-collisions |
2 | Crowded mines with many players. |
spigot.yml |
merge-radius.item |
2.5 | Merges dropped items into fewer stacks. |
bukkit.yml |
spawn-limits.monsters |
0 (or mob spawning off) | Prison doesn't need mobs. |
# config/paper-world-defaults.yml (only the keys you change)
chunks:
entity-per-chunk-save-limit:
item: 64
experience_orb: 16
collisions:
max-entity-collisions: 2
Edit these with the server stopped. Auto pickup (step 9) removes most dropped items anyway.
Updates and resets
- Plugin updates: lock a backup, put the new jar in
plugins/update/, restart. Update Prison on a test copy first and read its changelog: rank and mine data formats occasionally change. - Minecraft version updates: wait until Prison, your enchant plugin and WorldGuard all support the new version. Players can join from newer clients in the meantime with ViaVersion.
- Economy resets ("seasons"): some Prison servers reset every few months: everyone back to A, a fresh economy, a new spawn. To do it, lock a backup, then reset ranks with
ranks set rank *all* A default(check the syntax withranks set rank helpfirst), reset balances with EssentialsX (eco reset **), and reset LuckPerms groups if your perks depend on rank. Announce resets weeks in advance and give returning players something (a cosmetic, a title) so they feel rewarded.
Launch checklist
- [ ] Paper on a pinned Minecraft version;
pluginsshows every plugin green. - [ ]
prison versionshows your economy (EssentialsX via Vault) and LuckPerms. - [ ] Every mine placed, filled, with a spawn point, liner and WorldGuard region.
- [ ] Mine reset timers set and staggered;
spark tpsstays at 20 during resets. - [ ] LuckPerms groups
a–z, themine-rankstrack, and the ladder command; a test player ranks up and changes group. - [ ] Prices set from your own measurements; A to E play-tested with a stopwatch.
- [ ] Sell prices checked against every shop buy price.
- [ ] Prestige enabled and rewarded.
- [ ] Spawn protected; global WorldGuard deny in place; non-op test player can't grief.
- [ ] Starter kit, tutorial signs,
/rules. - [ ] Staff on a separate track with only the nodes they need; few ops.
- [ ] CoreProtect running.
- [ ] Backup every 6 hours and a daily restart, both tested with Run now; a locked launch-day backup.
Common problems
| Problem | Likely cause | Fix |
|---|---|---|
| Ranks module won't load | No economy registered | Install Vault and EssentialsX, restart, check prison version. |
/rankup says no permission |
Players lack ranks.user |
lp group default permission set ranks.user true. |
| Players can't break blocks in their mine | Global WorldGuard deny with no mine region | Create a region over the mine with block-break allow (step 5). |
| Players can mine in mines above their rank | Mine access by rank is off, or a WorldGuard region allows everyone | Run mines set mineAccessByRank help and turn it on for the mine. |
| LuckPerms group doesn't change on rank-up | Ladder command missing, or group names don't match rank names | ranks ladder command add default lp user {player} parent settrack mine-ranks {targetRank}; check groups exist for every rank. |
| Lag spike every few minutes | Big mines resetting together | Stagger reset times, shrink mines, lower thresholds. |
| Mine resets constantly | Reset threshold set very high | Lower it to 80% or below. |
| A mine reset wiped a build | mines set area was run in the wrong place |
Restore from backup or CoreProtect (co rollback t:1h r:#worldedit with the area selected). |
| Players finish all ranks in a day | Prices don't include multipliers, Fortune or enchants | Redo step 8 with every multiplier included. |
| Economy inflates | A buy/sell loop, or too-generous multipliers | Compare shop buy prices with sell-all prices; lower multipliers; consider a reset. |
| Players stuck at a rank for hours | Rank multiplier higher than mine value growth | Lower mult, or add more valuable blocks to that mine. |
| Items pile up on the ground | Auto pickup off or inventory full | Enable auto pickup; give auto-sell; set an item save limit. |
Prison placeholders show raw %...% text |
PlaceholderAPI missing or not hooked | Install PlaceholderAPI, restart, check papi list. |
Going further
- Gangs: team-based Prison with shared banks and gang leaderboards. Several plugins exist; check version support.
- Mine events: Prison's BlockEvents run commands when specific blocks are mined (for example, a 1-in-1000 chance of a key). Its docs page Using BlockEvents explains them.
- A network: split Prison into its own server behind Velocity with a lobby. Velocity networks
- Shared data: store LuckPerms in MySQL if you run more than one server. Databases
- Prison's full documentation is on GitHub (PrisonTeam/Prison,
docsfolder), andprison helplists every command in game.

